aboutsummaryrefslogtreecommitdiffstats
path: root/src/core/SkBitmapProcShader.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/core/SkBitmapProcShader.h')
-rw-r--r--src/core/SkBitmapProcShader.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/core/SkBitmapProcShader.h b/src/core/SkBitmapProcShader.h
index 5179ff8bf2..30f860a9bf 100644
--- a/src/core/SkBitmapProcShader.h
+++ b/src/core/SkBitmapProcShader.h
@@ -18,7 +18,7 @@ struct SkBitmapProcState;
class SkBitmapProcShader : public SkShader {
public:
SkBitmapProcShader(const SkBitmap& src, TileMode tx, TileMode ty,
- const SkMatrix* localMatrix = NULL);
+ const SkMatrix* localMatrix = nullptr);
// overrides from SkShader
bool isOpaque() const override;
@@ -72,7 +72,7 @@ private:
// yet found a situation where the size below isn't big enough.
typedef SkSmallAllocator<3, 1152> SkTBlitterAllocator;
// If alloc is non-NULL, it will be used to allocate the returned SkShader, and MUST outlive
// the SkShader.
SkShader* SkCreateBitmapShader(const SkBitmap& src, SkShader::TileMode, SkShader::TileMode,
const SkMatrix* localMatrix, SkTBlitterAllocator* alloc);
@@ -72,7 +72,7 @@ private:
// yet found a situation where the size below isn't big enough.
typedef SkSmallAllocator<3, 1152> SkTBlitterAllocator;
-// If alloc is non-NULL, it will be used to allocate the returned SkShader, and MUST outlive
+// If alloc is non-nullptr, it will be used to allocate the returned SkShader, and MUST outlive
// the SkShader.
SkShader* SkCreateBitmapShader(const SkBitmap& src, SkShader::TileMode, SkShader::TileMode,